#' 82398 Sampling Method (Codes)
#'
#' A table containing the USGS Sampling Method (Codes) parameter codes.
#'
#' @format A data frame with 63 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_82398"
#> [1] "pmcode_82398"
